@@ -195,12 +195,14 @@ mod tests {
     #[test]
     fn token_validity() -> anyhow::Result<()> {
         let node = LocalNode::generate();
-        let cell = FullCell::generate(node);
+        let cell = FullCell::generate(node)?;
         let clock = Clock::new();
 
         let mut token = AuthToken::new(cell.cell(), &clock, None)?;
         assert!(token.is_valid(cell.cell(), &clock).is_ok());
 
+        debug!("Auth token: {:?}", token);
+
         // modify signature, shouldn't be valid anymore
         token.signed.signature = vec![0, 1, 2, 3];
         assert!(token.is_valid(cell.cell(), &clock).is_err());
@@ -215,7 +217,7 @@ mod tests {
     #[test]
     fn token_expiration() -> anyhow::Result<()> {
         let node = LocalNode::generate();
-        let cell = FullCell::generate(node.clone());
+        let cell = FullCell::generate(node.clone())?;
 
         let now = Instant::now();
         let clock = Clock::new_fixed_mocked(now);
@@ -237,7 +239,7 @@ mod tests {
     #[test]
     fn token_encoding() -> anyhow::Result<()> {
         let node = LocalNode::generate();
-        let cell = FullCell::generate(node.clone());
+        let cell = FullCell::generate(node.clone())?;
 
         let clock = Clock::new();
         let expiry = clock.consistent_time(node.node());
